==> sovix-0.0.1.5.tar.gz: sovix-0.0.1.5/websrc/Variables.php <==
<?php /* Copyright (C) 2008 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2008 David Englund.
This entire article is distributed under the GNU Free Documentation
License, Version 1.2 or any later version.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}
require_once "$sovix__directory__src/header.inc"; ?>

<p>This is a list of pre-defined PHP variables used by Sovix:</p>

<?php
$tmp="DOCUMENT_ROOT"; echo "$tmp = ".$_SERVER["$tmp"]." (variable to locate Sovix and sovix__directory__document_root)<br />";
echo "_GET<br />";
$tmp="HTTP_USER_AGENT"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
$tmp="SCRIPT_FILENAME"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
$tmp="PHP_SELF"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
echo "_POST<br />";
$tmp="REMOTE_ADDR"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
$tmp="REQUEST_URI"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
echo "_SERVER<br />";
$tmp="SERVER_ADDR"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
$tmp="SERVER_NAME"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
echo "_SESSION<br />";
?>

<p>Pre-defined variables we avoid since some web server configuration don't allow them:</p>
<?php
$tmp="PATH_TRANSLATED"; echo "$tmp = ".$_SERVER["$tmp"]." (SCRIPT_FILENAME is in used instead)<br />";
echo "SERVER_SIGNATURE";
?>

<?php require_once "$sovix__directory__src/footer.inc"; ?>

==> sovix-0.0.1.6-rc4.tar.gz: sovix-0.0.1.6-rc4/websrc/Variables.php <==
<?php /* Copyright (C) 2008 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2008 David Englund.
Permission is granted to copy, distribute and/or modify this document
under the terms of the GNU Free Documentation License, Version 1.2 or any
later version published by the Free Software Foundation; with no Invariant
Sections, with no Front-Cover Texts, and with no Back-Cover Texts.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}
require_once "$sovix__directory__src/header.inc"; ?>

<p>This is a list of pre-defined PHP variables used by Sovix:</p>

<?php
$tmp="DOCUMENT_ROOT"; echo "$tmp = ".$_SERVER["$tmp"]." (variable to locate Sovix and sovix__directory__document_root)<br />";
echo "_GET<br />";
$tmp="HTTP_USER_AGENT"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
$tmp="SCRIPT_FILENAME"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
$tmp="PHP_SELF"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
echo "_POST<br />";
$tmp="REMOTE_ADDR"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
$tmp="REQUEST_URI"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
echo "_SERVER<br />";
$tmp="SERVER_ADDR"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
$tmp="SERVER_NAME"; echo "$tmp = ".$_SERVER["$tmp"]."<br />";
echo "_SESSION<br />";
?>

<p>Pre-defined variables we avoid since some web server configuration don't allow them:</p>
<?php
$tmp="PATH_TRANSLATED"; echo "$tmp = ".$_SERVER["$tmp"]." (SCRIPT_FILENAME is in used instead)<br />";
echo "SERVER_SIGNATURE";
?>

<?php require_once "$sovix__directory__src/footer.inc"; ?>
